# spatial_autocorrelation
Performing Moran's I to conduct correlation analysis on topological relationship.

In statistics, Moran's I is a measure of spatial autocorrelation developed by Patrick Alfred Pierce Moran. Spatial autocorrelation is characterized by a correlation in a signal among nearby locations in space. Spatial autocorrelation is more complex than one-dimensional autocorrelation because spatial correlation is multi-dimensional (i.e. 2 or 3 dimensions of space) and multi-directional.[1]

From the example.py, you can see how the values of blocks are correlated with the values of neighbours spatially
![image](https://user-images.githubusercontent.com/69416199/143538881-3c6db158-74ba-4f41-a32c-428d06193475.png)


Reference(s):
[1] https://en.wikipedia.org/wiki/Moran%27s_I
[2] https://www.statology.org/morans-i/
[3] https://pro.arcgis.com/en/pro-app/latest/tool-reference/spatial-statistics/h-how-spatial-autocorrelation-moran-s-i-spatial-st.htm
